summaryrefslogtreecommitdiff
path: root/searx/engines/vimeo.py
diff options
context:
space:
mode:
authorAdam Tauber <adam.tauber@balabit.com>2015-01-07 11:48:36 +0100
committerAdam Tauber <adam.tauber@balabit.com>2015-01-07 11:48:36 +0100
commit05be069f424f478174b65e42fc2865148850060c (patch)
treef1ce53d468a72bc751138a949355b8c0696e803d /searx/engines/vimeo.py
parent3b672039aab207d0002eac9d7406f0c5b3239df0 (diff)
parenta723936ad4d36a8454f98017cf611ebd02343147 (diff)
downloadsearxng-05be069f424f478174b65e42fc2865148850060c.tar.gz
searxng-05be069f424f478174b65e42fc2865148850060c.zip
Merge branch 'integrated-videos' of https://github.com/Cqoicebordel/searx into Cqoicebordel-integrated-videos
Conflicts: searx/engines/vimeo.py
Diffstat (limited to 'searx/engines/vimeo.py')
-rw-r--r--searx/engines/vimeo.py24
1 files changed, 17 insertions, 7 deletions
diff --git a/searx/engines/vimeo.py b/searx/engines/vimeo.py
index 3949a7299..39033c591 100644
--- a/searx/engines/vimeo.py
+++ b/searx/engines/vimeo.py
@@ -1,4 +1,4 @@
-## Vimeo (Videos)
+# Vimeo (Videos)
#
# @website https://vimeo.com/
# @provide-api yes (http://developer.vimeo.com/api),
@@ -7,15 +7,16 @@
# @using-api no (TODO, rewrite to api)
# @results HTML (using search portal)
# @stable no (HTML can change)
# @parse url, title, publishedDate, thumbnail
#
# @todo rewrite to api
# @todo set content-parameter with correct data
from urllib import urlencode
from lxml import html
+from HTMLParser import HTMLParser
+from searx.engines.xpath import extract_text
from dateutil import parser
-from cgi import escape
# engine dependent config
categories = ['videos']
@@ -32,6 +33,10 @@ title_xpath = './a/div[@class="data"]/p[@class="title"]'
content_xpath = './a/img/@src'
publishedDate_xpath = './/p[@class="meta"]//attribute::datetime'
+embedded_url = '<iframe data-src="//player.vimeo.com/video{videoid}" ' +\
+ 'width="540" height="304" frameborder="0" ' +\
+ 'webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>'
+
# do search-request
def request(query, params):
@@ -46,13 +51,17 @@ def response(resp):
results = []
dom = html.fromstring(resp.text)
+ p = HTMLParser()
# parse results
for result in dom.xpath(results_xpath):
- url = base_url + result.xpath(url_xpath)[0]
- title = escape(html.tostring(result.xpath(title_xpath)[0], method='text', encoding='UTF-8').decode("utf-8"))
- thumbnail = result.xpath(content_xpath)[0]
- publishedDate = parser.parse(result.xpath(publishedDate_xpath)[0])
+ videoid = result.xpath(url_xpath)[0]
+ url = base_url + videoid
+ title = p.unescape(extract_text(result.xpath(title_xpath)))
+ thumbnail = extract_text(result.xpath(content_xpath)[0])
+ publishedDate = parser.parse(extract_text(
+ result.xpath(publishedDate_xpath)[0]))
+ embedded = embedded_url.format(videoid=videoid)
# append result
results.append({'url': url,
@@ -60,6 +69,7 @@ def response(resp):
'content': '',
'template': 'videos.html',
'publishedDate': publishedDate,
+ 'embedded': embedded,
'thumbnail': thumbnail})
# return results
@@ -7,15 +7,16 @@
# @results HTML (using search portal)
# @stable no (HTML can change)
-# @parse url, title, publishedDate, thumbnail
+# @parse url, title, publishedDate, thumbnail, embedded
#
# @todo rewrite to api